Template blocks — django-frontend 1.3.0 documentation

### Navigation

- index
- next |
- previous |
- django-frontend 1.3.0 documentation »

# Template blocks

Use the included template blocks to suit your needs.

## html

Override the HTML doctype, or use in conjunction with {% djfrontend_h5bp_html ‘’ %} to change the HTML lang attribute.

## title

Add your application specific title to the title tag.

## meta_viewport

Override the default meta viewport’s content attribute.

## meta_description

Add your application specific information to the meta description.

## head_css

Parent CSS block to override or extend the included CSS files.

## head_js

Override or extend with JavaScript files that need to loaded in the head.

## body_id

Add an id to the body if needed.

## body_class

Add class(es) to the body if needed.

## body_content

Override the Internet Explorer warning, and/or extend with the main content from your application.

## body_js

Override or extend the included JavaScript files with any file that does not need to be loaded in the head.

### Navigation

- index
- next |
- previous |
- django-frontend 1.3.0 documentation »